@@ -4,7 +4,7 @@ use Carp qw(croak);
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 has raw => (
     is => 'rwp',
@@ -48,7 +48,7 @@ __END__
 
 =head1 NAME
 
-L<MARC::Spec::Comparisonstring|MARC::Spec::Comparisonstring>
+L<MARC::Spec::Comparisonstring|MARC::Spec::Comparisonstring> - comparison string specification
 
 =head1 SYNOPSIS
 
@@ -115,4 +115,4 @@ L<MARC::Spec::Subfield|MARC::Spec::Subfield>,
 L<MARC::Spec::Structure|MARC::Spec::Structure>,
 L<MARC::Spec::Subspec|MARC::Spec::Subspec>
 
-=cut
\ No newline at end of file
+=cut
