@@ -5,7 +5,7 @@ use namespace::clean;
 
 extends 'MARC::Spec::Structure';
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 has tag => (
     is => 'rw',
@@ -34,7 +34,7 @@ __END__
 
 =head1 NAME
 
-L<MARC::Spec::Field|MARC::Spec::Field>
+L<MARC::Spec::Field|MARC::Spec::Field> - field specification
 
 =head1 SYNOPSIS
 
@@ -203,4 +203,4 @@ L<MARC::Spec::Structure|MARC::Spec::Structure>,
 L<MARC::Spec::Comparisonstring|MARC::Spec::Comparisonstring>,
 L<MARC::Spec::Parser|MARC::Spec::Parser>
 
-=cut
\ No newline at end of file
+=cut
