@@ -10,7 +10,7 @@ require MARC::Spec::Comparisonstring;
 require MARC::Spec::Subspec;
 use namespace::clean;
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 has spec => (
     is => 'rw',
@@ -299,7 +299,7 @@ __END__
 
 =head1 NAME
 
-L<MARC::Spec::Parser|MARC::Spec::Parser>
+L<MARC::Spec::Parser|MARC::Spec::Parser> - parses a MARCspec as string
 
 =head1 SYNOPSIS
 
