@@ -5,7 +5,7 @@ use Const::Fast;
 use Carp qw(croak);
 use namespace::clean;
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 const my $NO_LENGTH => -1;
 const my $LAST => '#';
@@ -245,7 +245,7 @@ __END__
 
 =head1 NAME
 
-L<MARC::Spec::Structure|MARC::Spec::Structure>
+L<MARC::Spec::Structure|MARC::Spec::Structure> - base class
 
 =head1 SYNOPSIS
 
