@@ -3,7 +3,7 @@ package MARC::Spec::Subfield;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 extends 'MARC::Spec::Structure';
 
@@ -25,7 +25,7 @@ __END__
 
 =head1 NAME
 
-L<MARC::Spec::Subfield|MARC::Spec::Subfield>
+L<MARC::Spec::Subfield|MARC::Spec::Subfield> - subfield specification
 
 =head1 SYNOPSIS
 
@@ -177,4 +177,4 @@ L<MARC::Spec::Structure|MARC::Spec::Structure>,
 L<MARC::Spec::Comparisonstring|MARC::Spec::Comparisonstring>,
 L<MARC::Spec::Parser|MARC::Spec::Parser>
 
-=cut
\ No newline at end of file
+=cut
