@@ -3,7 +3,7 @@ package MARC::Spec::Subspec;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 has left => (
     is => 'rw',
@@ -40,7 +40,7 @@ __END__
 
 =head1 NAME
 
-L<MARC::Spec::Subspec|MARC::Spec::Subspec>
+L<MARC::Spec::Subspec|MARC::Spec::Subspec> - subspec specification
 
 =head1 SYNOPSIS
 
